'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _fs = require('fs');

var fs = _interopRequireWildcard(_fs);

var _alertify = require('alertify.js');

var _alertify2 = _interopRequireDefault(_alertify);

var _pdf_utils = require('../../utils/pdf_utils');

var _pdf_utils2 = _interopRequireDefault(_pdf_utils);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

var mutations = {
	activeList: function activeList(state, event) {
		document.querySelectorAll('.book-list').forEach(function (e) {
			return e.classList.remove('active');
		});

		if (event) event.path[1].classList.add('active');
	}
};

var actions = {
	drop: function drop(_ref, listId) {
		var commit = _ref.commit;

		var dragBookId = localStorage.getItem('dragBookId');
		var dragListId = localStorage.getItem('dragListId');

		if (dragBookId && dragListId) {
			bookListDb.findOne({ _id: dragListId }, function (err, doc) {
				var dragBook = doc.books.filter(function (b) {
					return b.bookId == dragBookId;
				})[0];
				dragBook.listId = listId;
				if (dragBook) bookListDb.update({ _id: dragListId }, { $pull: { books: { bookId: dragBookId } } }, function (err) {
						bookListDb.update({ _id: listId }, { $push: { books: dragBook } }, function (err) {
							commit('updateBookContents', dragListId);
						});
					});
			});
		}
	},
	addListBook: function addListBook(_ref2, args) {
		var rootState = _ref2.rootState,
		    commit = _ref2.commit;

		var selectedFiles = args.event.target.files;
		if (selectedFiles.length > 0) commit('isLoading');

		if (selectedFiles.length > 20) selectedFiles = Array.from(selectedFiles).slice(0, 20);
		var filePaths = Object.keys(selectedFiles).map(function (f) {
			return selectedFiles[f].path;
		});

		if (!fs.existsSync(userData + '/book-images')) fs.mkdirSync(userData + '/book-images');

		var books = [],
		    tempAuthors = new Set(),
		    authors = new Set();

		new Promise(function (resolve) {
			authorListDb.find({}, function (e, docs) {
				return resolve(docs.map(function (a) {
					return a.authorName;
				}));
			});
		}).then(function (tempAuthors) {
			new Promise(function (resolve) {
				filePaths.forEach(function (bookPath) {
					var data = fs.readFileSync(bookPath);

					var bookId = args.listId + '_' + Math.random().toString(36).substr(2, 9);
					var bookImagePath = userData + '/book-images/' + bookId + '.jpeg';

					(0, _pdf_utils2.default)(data, bookImagePath).then(function (props) {
						var metadata = props.meta.metadata != null ? props.meta.metadata.metadata : {};
						var info = props.meta.info != null ? props.meta.info : {};

						var bookName = (metadata['dc:title'] != '()' ? metadata['dc:title'] : '') || bookPath.match(/.*\/(.+?)\./).pop() || 'Untitled';
						var bookAuthor = info.Author || metadata['dc:author'] || 'Unknown Author';
						var bookPageCount = props.pageCount;

						authors.add(bookAuthor);

						books.push({
							bookId: bookId,
							bookImagePath: bookImagePath,
							bookPath: bookPath,
							bookName: bookName,
							bookAuthor: bookAuthor,
							bookPageCount: bookPageCount,
							listId: args.listId
						});

						if (books.length == selectedFiles.length) resolve(books);
					});
				});
			}).then(function (books) {
				bookListDb.update({ _id: args.listId }, { $push: { books: { $each: books } } }, function (err, num) {
					var _tempAuthors = Array.from(tempAuthors);
					var _authors = Array.from(authors).filter(function (e) {
						return _tempAuthors.indexOf(e) === -1;
					}).map(function (e) {
						return { authorName: e };
					});

					authorListDb.insert(_authors, function (err) {
						return commit('updateAuthorsList');
					});
					commit('updateBookContents', args.listId);
					commit('isLoading');
				});
			});
		});
	},
	openBookList: function openBookList(_ref3, args) {
		var commit = _ref3.commit;

		commit('updateBookContents', args.listId);
		commit('activeList', args.event);
	},
	remove: function remove(_ref4, args) {
		var commit = _ref4.commit;

		_alertify2.default.okBtn('Yes').cancelBtn('No').confirm('Do you delete the [' + args.listName + '] list ?').then(function (value) {
			value.event.preventDefault();

			if (value.buttonClicked == 'ok') {
				bookListDb.findOne({ _id: args.listId }, function (err, selectedList) {
					selectedList.books.forEach(function (book) {
						fs.unlink(book.bookImagePath);

						var bookCount = 0;
						bookListDb.find({ _id: { $ne: args.listId } }, function (err, lists) {
							lists.forEach(function (list) {
								list.books.forEach(function (b) {
									if (b.bookAuthor == book.bookAuthor) bookCount++;
								});
							});

							if (bookCount == 0 || lists.length == 0) {
								authorListDb.remove({ authorName: book.bookAuthor });
								commit('updateAuthorsList');
							}
						});
					});

					bookListDb.remove({ _id: args.listId }, function (err) {
						_alertify2.default.delay(3000).success(args.listName + ' list deleted.');

						commit('updateBookLists');
						commit('updateBookContents');
					});
				});
			}
		});
	}
};

exports.default = {
	actions: actions,
	mutations: mutations
};