'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var state = {
	newListName: '',
	newListInput: false,
	bookLists: [],
	authorsList: []
};

var getters = {
	bookLists: function bookLists(state) {
		return state.bookLists;
	},
	authorsList: function authorsList(state) {
		return state.authorsList;
	},
	newListInput: function newListInput(state) {
		return state.newListInput;
	},
	newListName: function newListName(state) {
		return state.newListName;
	}
};

var mutations = {
	updateBookLists: function updateBookLists(state) {
		bookListDb.find({}).sort({ listName: 1 }).exec(function (err, docs) {
			state.bookLists = docs;
		});
	},
	updateAuthorsList: function updateAuthorsList(state) {
		authorListDb.find({}).sort({ authorName: 1 }).exec(function (err, docs) {
			state.authorsList = docs;
		});
	},
	updateNewListName: function updateNewListName(state, val) {
		state.newListName = val;
	}
};

var actions = {
	addNewList: function addNewList(_ref) {
		var state = _ref.state,
		    commit = _ref.commit;

		if (state.newListInput) {
			var newListName = state.newListName.trim();
			if (newListName) {
				bookListDb.insert({
					listName: newListName,
					books: []
				}, function () {
					return commit('updateBookLists');
				});
			}
			state.newListName = '';
			state.newListInput = false;
		} else {
			state.newListInput = true;
		}
	},
	bookSearching: function bookSearching(_ref2, event) {
		var rootState = _ref2.rootState,
		    commit = _ref2.commit;

		commit('activeList');

		var results = [];
		var query = event.target.value.toLowerCase().trim();

		if (query) {
			bookListDb.find({}, function (er, docs) {
				docs.forEach(function (list) {
					list.books.forEach(function (book) {
						if (book.bookName.toLowerCase().indexOf(query) !== -1) results.push(book);else if (book.bookAuthor.toLowerCase().indexOf(query) !== -1) results.push(book);
					});
				});
			});
		}
		rootState.booksContent.booksContent = results;
	}
};

exports.default = {
	state: state,
	mutations: mutations,
	getters: getters,
	actions: actions
};